﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.UltraChart.Resources.Appearance;
using System.Collections;
using Infragistics.UltraChart.Shared.Styles;
using System.Threading;

namespace EscalateTestApp
{
    public partial class ChartTest : Form
    {
        private Random rand = new Random(100);
        private int MaxDataPointsOnChart = 1000;
        public ChartTest()
        {
            InitializeComponent();
            BuildChart();

            ThreadPool.QueueUserWorkItem(Tick);
        }

        void Tick(object param)
        {
            int i = 0;
            while (i < MaxDataPointsOnChart)
            {
                var item = new NumericTimeDataPoint(DateTime.Now, rand.NextDouble(), "", false);
                ((NumericTimeSeries)ultraChart.CompositeChart.ChartLayers[0].Series[0]).Points.Add(item);
                ++i;
                Thread.Sleep(1000);
            }
        }

        private void BuildChart()
        {
            var area = new ChartArea();
            area.Border.Thickness = 0;
            this.ultraChart.CompositeChart.ChartAreas.Add(area);
            var xAxis = this.CreateXAxis();
            area.Axes.Add(xAxis);
            var yAxisPerSecond = this.CreateYPerSecondAxis();
            area.Axes.Add(yAxisPerSecond);
            ChartLayerAppearance newPerSecondLayer = this.BuildPerSecondLayer(xAxis, yAxisPerSecond, area);
           
            this.ultraChart.CompositeChart.ChartLayers.Add(newPerSecondLayer);
            var series = new NumericTimeSeries();
            var coll=  new PaintElement(Color.Green);
            series.PEs.Add(coll);
            ultraChart.CompositeChart.ChartLayers[0].Series.Add(series);
        }

        private ChartLayerAppearance BuildPerSecondLayer(AxisItem xAxis, AxisItem yAxis, ChartArea area)
        {
            ChartLayerAppearance layer = new ChartLayerAppearance();
            layer.AxisX = xAxis;
            layer.AxisY = yAxis;
            layer.ChartArea = area;
            layer.ChartType = ChartType.LineChart;

            return layer;
        }

        private AxisItem CreateXAxis()
        {
            AxisItem item = new AxisItem();
            item.DataType = AxisDataType.Time;
            item.OrientationType = AxisNumber.X_Axis;
            item.TickmarkStyle = AxisTickStyle.Smart;
            item.Labels.Orientation = TextOrientation.VerticalLeftFacing;
            
            item.LineThickness = 1;
            item.MajorGridLines.Visible = false;
            item.MinorGridLines.Visible = false;

            return item;
        }

        protected virtual AxisItem CreateYPerSecondAxis()
        {
            AxisItem item = new AxisItem();
            item.DataType = AxisDataType.Numeric;
            item.OrientationType = AxisNumber.Y_Axis;
            item.TickmarkStyle = AxisTickStyle.Smart;
            item.LineThickness = 0;

            return item;
        }
    }
}
